@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2011 - 2023 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2011 - 2022 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -18,6 +18,11 @@ DBusLockFrontService::~DBusLockFrontService()
 {
 }
 
+bool DBusLockFrontService::visible() const
+{
+    return parent()->Visible();
+}
+
 void DBusLockFrontService::Show()
 {
     parent()->Show();
