@@ -219,21 +219,6 @@ bool isDeepinAuth()
     return true;
 }
 
-uint timeFromString(QString time)
-{
-#ifndef ENABLE_DSS_SNIPE
-    if (time.isEmpty()) {
-        return QDateTime::currentDateTime().toTime_t();
-    }
-    return QDateTime::fromString(time, Qt::ISODateWithMs).toLocalTime().toTime_t();
-#else
-    if (time.isEmpty()) {
-        return QDateTime::currentDateTime().toSecsSinceEpoch();
-    }
-    return QDateTime::fromString(time, Qt::ISODateWithMs).toLocalTime().toSecsSinceEpoch();
-#endif
-}
-
 void setAppType(int type)
 {
     appType = type;
@@ -371,3 +356,21 @@ bool isSleepLock()
     return value.toBool();
 }
 #endif
+
+QString qtifyName(const QString &name) {
+    bool next_cap = false;
+    QString result;
+    
+    for (auto it = name.cbegin(); it != name.cend(); ++it) {
+        if (*it == '-') {
+            next_cap = true;
+        } else if (next_cap) {
+            result.append(it->toUpper());
+            next_cap = false;
+        } else {
+            result.append(*it);
+        }
+    }
+    
+    return result;
+}
\ No newline at end of file
