@@ -9,6 +9,8 @@
 #include "userinfo.h"
 #include "dconfig_helper.h"
 #include "login_plugin_util.h"
+#include "mfasequencecontrol.h"
+#include "signal_bridge.h"
 
 #include <DSysInfo>
 
@@ -324,6 +326,8 @@ void GreeterWorker::initConnections()
     // 监听terminal锁定状态
     QDBusConnection::systemBus().connect(DSS_DBUS::accountsService, DSS_DBUS::accountsPath, "org.freedesktop.DBus.Properties",
                                          "PropertiesChanged", this, SLOT(terminalLockedChanged(QDBusMessage)));
+
+    connect(&SignalBridge::ref(), &SignalBridge::requestSendExtraInfo, this, &GreeterWorker::sendExtraInfo);
 }
 
 void GreeterWorker::initData()
@@ -333,38 +337,47 @@ void GreeterWorker::initData()
         m_model->setSEType(true);
     }
 
-    /* com.deepin.daemon.Accounts */
-    m_model->updateUserList(m_accountsInter->userList());
-    m_model->updateLoginedUserList(m_loginedInter->userList());
+    auto list = m_accountsInter->userList();
+    if (!list.isEmpty()) {
+        /* com.deepin.daemon.Accounts */
+        m_model->updateUserList(list);
+        m_model->updateLoginedUserList(m_loginedInter->userList());
 
-    m_model->setUserlistVisible(valueByQSettings<bool>("", "userlist", true));
-    /* com.deepin.udcp.iam */
-    QDBusInterface ifc(DSS_DBUS::udcpIamService, DSS_DBUS::udcpIamPath, DSS_DBUS::udcpIamService, QDBusConnection::systemBus(), this);
-    const bool allowShowCustomUser = (!m_model->userlistVisible()) || valueByQSettings<bool>("", "loginPromptInput", false) ||
-        ifc.property("Enable").toBool() || checkIsADDomain();
-    m_model->setAllowShowCustomUser(allowShowCustomUser);
+        m_model->setUserlistVisible(valueByQSettings<bool>("", "userlist", true));
+        /* com.deepin.udcp.iam */
+        QDBusInterface ifc(DSS_DBUS::udcpIamService, DSS_DBUS::udcpIamPath, DSS_DBUS::udcpIamService, QDBusConnection::systemBus(), this);
+        const bool allowShowCustomUser = (!m_model->userlistVisible()) || valueByQSettings<bool>("", "loginPromptInput", false) ||
+            ifc.property("Enable").toBool() || checkIsADDomain();
+        m_model->setAllowShowCustomUser(allowShowCustomUser);
 
-    /* init current user */
-    if (DSysInfo::deepinType() == DSysInfo::DeepinServer || m_model->allowShowCustomUser()) {
-        // 如果是服务器版本或者loginPromptInput配置为true，默认显示空用户
-        std::shared_ptr<User> user(new User());
-        m_model->setIsServerModel(DSysInfo::deepinType() == DSysInfo::DeepinServer);
-        m_model->addUser(user);
-        if (DSysInfo::deepinType() == DSysInfo::DeepinServer || valueByQSettings<bool>("", "loginPromptInput", false) || !m_model->userlistVisible()) {
-            m_model->updateCurrentUser(user);
+        /* init current user */
+        if (DSysInfo::deepinType() == DSysInfo::DeepinServer || m_model->allowShowCustomUser()) {
+            // 如果是服务器版本或者loginPromptInput配置为true，默认显示空用户
+            std::shared_ptr<User> user(new User());
+            m_model->setIsServerModel(DSysInfo::deepinType() == DSysInfo::DeepinServer);
+            m_model->addUser(user);
+            if (DSysInfo::deepinType() == DSysInfo::DeepinServer || valueByQSettings<bool>("", "loginPromptInput", false) || !m_model->userlistVisible()) {
+                m_model->updateCurrentUser(user);
+            } else {
+                /* com.deepin.dde.LockService */
+                m_model->updateCurrentUser(m_lockInter->CurrentUser());
+            }
         } else {
             /* com.deepin.dde.LockService */
             m_model->updateCurrentUser(m_lockInter->CurrentUser());
         }
-    } else {
-        /* com.deepin.dde.LockService */
-        m_model->updateCurrentUser(m_lockInter->CurrentUser());
-    }
 #ifndef ENABLE_DSS_SNIPE
     m_soundPlayerInter->PrepareShutdownSound(static_cast<int>(m_model->currentUser()->uid()));
 #else
     prepareShutdownSound();
 #endif
+    } else {
+        qCWarning(DDE_SHELL) << "dbus com.deepin.daemon.Accounts userList is empty, use ...";
+        m_model->setAllowShowCustomUser(true);
+        std::shared_ptr<User> user(new User());
+        m_model->addUser(user);
+        m_model->updateCurrentUser(user);
+    }
 
     /* com.deepin.daemon.Authenticate */
     if (m_authFramework->isDAStartupCompleted() ) {
@@ -908,7 +921,12 @@ void GreeterWorker::onAuthStateChanged(const int type, const int state, const QS
             case AS_Success:
                 if (m_model->currentModeState() != SessionBaseModel::ResetPasswdMode)
                     m_model->setCurrentModeState(SessionBaseModel::ModeStatus::PasswordMode);
-                m_resetSessionTimer->start();
+
+                // 处于序列化多因认证过程中时不要重置认证
+                if (MFASequenceControl::instance().currentAuthType() == AuthType::AT_None) {
+                    m_resetSessionTimer->start();
+                }
+
                 m_model->updateAuthState(AuthType(type), AuthState(state), message);
                 break;
             case AS_Failure:
@@ -1217,3 +1235,14 @@ void GreeterWorker::prepareShutdownSound()
     //soundPlayerInter.call("PrepareShutdownSound", static_cast<int>(m_model->currentUser()->uid()));
 }
 #endif
+
+void GreeterWorker::sendExtraInfo(const QString &account, AuthCommon::AuthType authType, const QString &info)
+{
+    switch (m_model->getAuthProperty().FrameworkState) {
+    case Available:
+        m_authFramework->sendExtraInfo(account, authType, info);
+        break;
+    default:
+        break;
+    }
+}
