@@ -24,7 +24,7 @@ public:
     QSize sizeHint() const override;
 
 #ifdef ENABLE_DSS_SNIPE
-    void updateLocale(const QString &locale, const QString &shortTimeFormat = "", const QString &longDateFormat = "");
+    void updateLocale(const QString &locale, const QString &shortTimeFormat = "", const QString &shortDateFormat = "");
 #endif // ENABLE_DSS_SNIPE
 
 public Q_SLOTS:
@@ -49,7 +49,7 @@ private:
 
 #ifdef ENABLE_DSS_SNIPE
     QString m_shortTimeFormat;
-    QString m_longDateFormat;
+    QString m_shortDateFormat;
 #endif // ENABLE_DSS_SNIPE
 };
 
