@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -37,11 +37,17 @@ void UT_ControlWidget::TearDown()
 
 TEST_F(UT_ControlWidget, init)
 {
+    m_controlWidget->setVirtualKBVisible(true);
     m_controlWidget->setUserSwitchEnable(true);
     m_controlWidget->setUserSwitchEnable(false);
     m_controlWidget->setSessionSwitchEnable(true);
     m_controlWidget->chooseToSession("");
     m_controlWidget->chooseToSession("aaaa");
+    m_controlWidget->rightKeySwitch();
 
+    m_controlWidget->rightKeySwitch();
+    m_controlWidget->leftKeySwitch();
+    m_controlWidget->showTips();
+    m_controlWidget->hideTips();
     QTest::keyRelease(m_controlWidget, Qt::Key_0, Qt::KeyboardModifier::NoModifier);
 }
