@@ -15,69 +15,69 @@
     </message>
     <message>
         <source>Verification failed, only one chance left</source>
-        <translation type="unfinished"/>
+        <translation>Verifizierung felgeschlagen, nurmehr ein Versuch möglich</translation>
     </message>
     <message>
         <source>Verify your Face ID</source>
-        <translation type="unfinished"/>
+        <translation>Face-ID verifizieren</translation>
     </message>
     <message>
         <source>Face ID locked, use password please</source>
-        <translation type="unfinished"/>
+        <translation>Face-ID gesperrt, bitte Passwort benützen</translation>
     </message>
     <message>
         <source>Device unavailable!</source>
-        <translation type="unfinished"/>
+        <translation>Gerät nicht verfübar!</translation>
     </message>
 </context>
 <context>
     <name>AuthFingerprint</name>
     <message>
         <source>Verify your fingerprint</source>
-        <translation type="unfinished"/>
+        <translation>Ihren Fingerabdruck verifizieren</translation>
     </message>
     <message>
         <source>Verification successful</source>
-        <translation type="unfinished"/>
+        <translation>Verifizierung erfolgreich</translation>
     </message>
     <message numerus="yes">
         <source>Verification failed, %n chances left</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>Verifikation fehlgeschlagen, nur noch ein Versuch möglich</numerusform><numerusform>Verifizierung fehlgeschlagen, noch %n Versuche</numerusform></translation>
     </message>
     <message>
         <source>Verification failed, only one chance left</source>
-        <translation type="unfinished"/>
+        <translation>Verifizierung fehlgeschlagen, nur noch ein Versuch möglich</translation>
     </message>
     <message>
         <source>Fingerprint locked, use password please</source>
-        <translation type="unfinished"/>
+        <translation>Fingerabdruck gesperrt, bitte Passwort benutzen</translation>
     </message>
 </context>
 <context>
     <name>AuthIris</name>
     <message>
         <source>Iris ID</source>
-        <translation type="unfinished"/>
+        <translation>Iris-ID</translation>
     </message>
     <message>
         <source>Verification successful</source>
-        <translation type="unfinished"/>
+        <translation>Verifizierung erfolgreich</translation>
     </message>
     <message numerus="yes">
         <source>Verification failed, %n chances left</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>Verifizierung fehlgeschlagen, noch %n Versuche übrig</numerusform><numerusform>Verifizierung fehlgeschlagen, noch %n Versuche</numerusform></translation>
     </message>
     <message>
         <source>Verification failed, only one chance left</source>
-        <translation type="unfinished"/>
+        <translation>Verifizierung fehlgeschlagen, nur noch ein Versuch möglich</translation>
     </message>
     <message>
         <source>Verify your Iris ID</source>
-        <translation type="unfinished"/>
+        <translation>Iris-ID verifizieren</translation>
     </message>
     <message>
         <source>Iris ID locked, use password please</source>
-        <translation type="unfinished"/>
+        <translation>Iris-ID gesperrt, bitte Passwort benützen</translation>
     </message>
 </context>
 <context>
@@ -103,108 +103,108 @@
     <name>AuthPassword</name>
     <message>
         <source>Verification successful</source>
-        <translation type="unfinished"/>
+        <translation>Verifizierung erfolgreich</translation>
     </message>
     <message numerus="yes">
         <source>Verification failed, %n chances left</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>Verifizierung fehlgeschlagen, noch %n Versuche übrig</numerusform><numerusform>Verifizierung fehlgeschlagen, noch %1 Versuche übrig</numerusform></translation>
     </message>
     <message>
         <source>Verification failed, only one chance left</source>
-        <translation type="unfinished"/>
+        <translation>Verifikation fehlgeschlagen, nur noch ein Versuch möglich</translation>
     </message>
     <message>
         <source>Wrong Password</source>
-        <translation type="unfinished"/>
+        <translation>Falsches Passwort</translation>
     </message>
     <message>
         <source>Password</source>
-        <translation type="unfinished"/>
+        <translation>Passwort</translation>
     </message>
     <message>
         <source>Please try again 1 minute later</source>
-        <translation type="unfinished"/>
+        <translation>Bitte in 1 Minute nochmals versuchen</translation>
     </message>
     <message numerus="yes">
         <source>Please try again %n minutes later</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>Bitte in %1 Minuten nochmals versuchen</numerusform><numerusform>Bitte in %n Minuten nochmals versuchen</numerusform></translation>
     </message>
     <message>
         <source>Reset Password</source>
-        <translation type="unfinished"/>
+        <translation>Passwort zurücksetzen</translation>
     </message>
     <message>
         <source>Forgot password?</source>
-        <translation type="unfinished"/>
+        <translation>Passwort vergessen?</translation>
     </message>
 </context>
 <context>
     <name>AuthSingle</name>
     <message>
         <source>Please try again 1 minute later</source>
-        <translation type="unfinished"/>
+        <translation>Bitte in 1 Minute nochmals versuchen</translation>
     </message>
     <message numerus="yes">
         <source>Please try again %n minutes later</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>Bitte in %1 Minuten nochmals versuchen</numerusform><numerusform>Bitte in %n Minuten nochmals versuchen</numerusform></translation>
     </message>
     <message>
         <source>Reset Password</source>
-        <translation type="unfinished"/>
+        <translation>Passwort zurücksetzen</translation>
     </message>
     <message>
         <source>Forgot password?</source>
-        <translation type="unfinished"/>
+        <translation>Passwort vergessen?</translation>
     </message>
 </context>
 <context>
     <name>AuthUKey</name>
     <message>
         <source>Verification successful</source>
-        <translation type="unfinished"/>
+        <translation>Verifizierung erfolgreich</translation>
     </message>
     <message numerus="yes">
         <source>Verification failed, %n chances left</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>Verifizierung fehlgeschlagen, noch %1 Versuche übrig</numerusform><numerusform>Verifizierung fehlgeschlagen, noch %1 Versuche</numerusform></translation>
     </message>
     <message>
         <source>Verification failed, only one chance left</source>
-        <translation type="unfinished"/>
+        <translation>Verifizierung fehlgeschlagen, nur noch ein Versuch möglich</translation>
     </message>
     <message>
         <source>Wrong PIN</source>
-        <translation type="unfinished"/>
+        <translation>Falsche PIN</translation>
     </message>
     <message>
         <source>UKey is required</source>
-        <translation type="unfinished"/>
+        <translation>UKey wird benötigt</translation>
     </message>
     <message>
         <source>Enter your PIN</source>
-        <translation type="unfinished"/>
+        <translation>PIN eingeben</translation>
     </message>
     <message numerus="yes">
         <source>Please try again %n minute(s) later</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>Bitte in %1 Minute(n) nochmals versuchen</numerusform><numerusform>Bitte in %n Minute(n) nochmals versuchen</numerusform></translation>
     </message>
     <message>
         <source>Please try again 1 minute later</source>
-        <translation type="unfinished"/>
+        <translation>Bitte in 1 Minute nochmals versuchen</translation>
     </message>
     <message numerus="yes">
         <source>Please try again %n minutes later</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>Bitte in %1 Minuten nochmals versuchen</numerusform><numerusform>Bitte in %n Minuten nochmals versuchen</numerusform></translation>
     </message>
 </context>
 <context>
     <name>AuthWidget</name>
     <message>
         <source>Account</source>
-        <translation type="unfinished"/>
+        <translation>Konto</translation>
     </message>
     <message numerus="yes">
         <source>Your password will expire in %n days, please change it timely</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>Ihr Passwort wird in %n Tagen abgelaufen sein, bitte zeitig erneuern</numerusform><numerusform>Ihr Passwort wird in %n Tagen ablaufen, bitte zeitig erneuern</numerusform></translation>
     </message>
     <message>
         <source>Password expired, please change</source>
@@ -230,18 +230,18 @@
     <name>GreeterWorker</name>
     <message>
         <source>Wrong account</source>
-        <translation type="unfinished"/>
+        <translation>Falsches Konto</translation>
     </message>
     <message>
         <source>Wrong Password</source>
-        <translation type="unfinished"/>
+        <translation>Falsches Passwort</translation>
     </message>
 </context>
 <context>
     <name>InhibitWarnView</name>
     <message>
         <source>Cancel</source>
-        <translation type="unfinished"/>
+        <translation>Abbrechen</translation>
     </message>
     <message>
         <source>The reason of inhibit.</source>
@@ -259,37 +259,37 @@
     <name>LockContent</name>
     <message>
         <source>Lock Screen</source>
-        <translation type="unfinished"/>
+        <translation>Bildschirm sperren</translation>
     </message>
     <message>
         <source>Failed to lock screen</source>
-        <translation type="unfinished"/>
+        <translation>Bildschirm sperren fehlgeschlagen</translation>
     </message>
 </context>
 <context>
     <name>LockWorker</name>
     <message>
         <source>Fingerprint verification timed out, please enter your password manually</source>
-        <translation type="unfinished"/>
+        <translation>Fingerabdruck-Verifizierung abgelaufen, bitte tippen Sie ihr Passwort ein</translation>
     </message>
     <message>
         <source>Failed to match fingerprint</source>
-        <translation type="unfinished"/>
+        <translation>Fingerabdrücke stimmen nicht überein</translation>
     </message>
 </context>
 <context>
     <name>MultiUsersWarningView</name>
     <message>
         <source>Cancel</source>
-        <translation type="unfinished"/>
+        <translation>Abbrechen</translation>
     </message>
     <message>
         <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
-        <translation type="unfinished"/>
+        <translation>Die obigen Benutzer sind noch angemeldet und Daten würden beim Herunterfahren verloren gehen, sind Sie sicher, dass Sie herunterfahren möchten?</translation>
     </message>
     <message>
         <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
-        <translation type="unfinished"/>
+        <translation>Die obigen Benutzer sind noch angemeldet und Daten würden beim erneuten Hochfahren verloren gehen, sind Sie sicher, dass Sie herunterfahren möchten?</translation>
     </message>
 </context>
 <context>
@@ -303,35 +303,35 @@
     <name>ShutdownWidget</name>
     <message>
         <source>Shut down</source>
-        <translation type="unfinished"/>
+        <translation>Herunterfahren</translation>
     </message>
     <message>
         <source>Reboot</source>
-        <translation type="unfinished"/>
+        <translation>Neu Booten</translation>
     </message>
     <message>
         <source>Suspend</source>
-        <translation type="unfinished"/>
+        <translation>Abschalten</translation>
     </message>
     <message>
         <source>Hibernate</source>
-        <translation type="unfinished"/>
+        <translation>Ruhezustand</translation>
     </message>
     <message>
         <source>Lock</source>
-        <translation type="unfinished"/>
+        <translation>Sperren</translation>
     </message>
     <message>
         <source>Log out</source>
-        <translation type="unfinished"/>
+        <translation>Abmelden</translation>
     </message>
     <message>
         <source>Switch user</source>
-        <translation type="unfinished"/>
+        <translation>Benutzer wechseln</translation>
     </message>
     <message>
         <source>Switch system</source>
-        <translation type="unfinished"/>
+        <translation>System wechseln</translation>
     </message>
     <message>
         <source>Update and Shut Down</source>
@@ -346,7 +346,7 @@
     <name>SystemMonitor</name>
     <message>
         <source>Start system monitor</source>
-        <translation type="unfinished"/>
+        <translation>System-Monitor starten</translation>
     </message>
 </context>
 <context>
@@ -402,59 +402,59 @@
     <name>WarningContent</name>
     <message>
         <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
-        <translation type="unfinished"/>
+        <translation>Die Programme verhindern ein Herunterfahren des Computers, und ein Erzwingen kann Datenverlust bedeuten.</translation>
     </message>
     <message>
         <source>To close the program, click Cancel, and then close the program.</source>
-        <translation type="unfinished"/>
+        <translation>Um das Programm zu beenden, klicken Sie auf Abbrechen und beenden dann das Programm.</translation>
     </message>
     <message>
         <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
-        <translation type="unfinished"/>
+        <translation>DIe Programme verhindern das erneute Hochfahren des Computers, ein Erzwingen kann Datenverlust bedeuten</translation>
     </message>
     <message>
         <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
-        <translation type="unfinished"/>
+        <translation>DIe Programme verhindern das Abschalten des Computers, ein Erzwingen kann Datenverlust bedeuten.</translation>
     </message>
     <message>
         <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
-        <translation type="unfinished"/>
+        <translation>DIe Programme verhindern den Ruhezustand des Computers, ein Erzwingen kann Datenverlust bedeuten</translation>
     </message>
     <message>
         <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
-        <translation type="unfinished"/>
+        <translation>DIe Programme verhindern das Abmelden des Computers, ein Erzwingen kann Datenverlust bedeuten</translation>
     </message>
     <message>
         <source>Shut down</source>
-        <translation type="unfinished"/>
+        <translation>Herunterfahren</translation>
     </message>
     <message>
         <source>Reboot</source>
-        <translation type="unfinished"/>
+        <translation>Neu Hochfahren</translation>
     </message>
     <message>
         <source>Suspend</source>
-        <translation type="unfinished"/>
+        <translation>Abschalten</translation>
     </message>
     <message>
         <source>Hibernate</source>
-        <translation type="unfinished"/>
+        <translation>Ruhezustand</translation>
     </message>
     <message>
         <source>Log out</source>
-        <translation type="unfinished"/>
+        <translation>Abmelden</translation>
     </message>
     <message>
         <source>Are you sure you want to shut down?</source>
-        <translation type="unfinished"/>
+        <translation>Sind Sie sicher, dass Sie sie herunterfahren möchten?</translation>
     </message>
     <message>
         <source>Are you sure you want to reboot?</source>
-        <translation type="unfinished"/>
+        <translation>Sind Sie sicher, dass Sie sie neu hochfahren möchten?</translation>
     </message>
     <message>
         <source>Are you sure you want to log out?</source>
-        <translation type="unfinished"/>
+        <translation>Sind Sie sicher, dass Sie sie sich abmelden möchten?</translation>
     </message>
     <message>
         <source>Update and Shut Down</source>
@@ -488,11 +488,11 @@
     <name>dss::module::NetworkModule</name>
     <message>
         <source>Turn on</source>
-        <translation type="unfinished"/>
+        <translation>Anschalten</translation>
     </message>
     <message>
         <source>Turn off</source>
-        <translation type="unfinished"/>
+        <translation>Abschalten</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
