@@ -27,7 +27,7 @@
     </message>
     <message>
         <source>Device unavailable!</source>
-        <translation>裝置不可用！</translation>
+        <translation>設備不可用！</translation>
     </message>
 </context>
 <context>
@@ -80,6 +80,25 @@
         <translation>虹膜ID已鎖定，請輸入密碼</translation>
     </message>
 </context>
+<context>
+    <name>AuthPasskey</name>
+    <message>
+        <source>Please plug in the security key</source>
+        <translation>請插入安全金鑰</translation>
+    </message>
+    <message>
+        <source>Verification successful</source>
+        <translation>驗證成功</translation>
+    </message>
+    <message>
+        <source>Verification failed</source>
+        <translation>驗證失敗</translation>
+    </message>
+    <message>
+        <source>Identifying the security key</source>
+        <translation>正在識別安全金鑰</translation>
+    </message>
+</context>
 <context>
     <name>AuthPassword</name>
     <message>
@@ -188,78 +207,23 @@
         <translation><numerusform>密碼將於%n天後過期，請及時修改密碼</numerusform></translation>
     </message>
     <message>
-        <source>Your password has expired. Please contact the administrator to change it.</source>
+        <source>Password expired, please change</source>
+        <translation>密碼已過期，請修改</translation>
+    </message>
+    <message>
+        <source>Your password has expired. Please contact the administrator to change it</source>
         <translation>您的密碼已過期，請聯絡管理員修改密碼</translation>
     </message>
     <message>
-        <source>Your password has expired. Please change it.</source>
-        <translation>密碼已過期，請修改</translation>
+        <source>Terminal locked, please contact administrator</source>
+        <translation>該裝置已被鎖定，請聯絡管理員</translation>
     </message>
 </context>
 <context>
-    <name>ChangePasswordWidget</name>
+    <name>DeepinAuthFramework</name>
     <message>
-        <source>Your password has expired. Please change it and log in again.</source>
-        <translation>您的密碼已過期，請修改密碼後重新登入</translation>
-    </message>
-    <message>
-        <source>Save</source>
-        <translation>保 存</translation>
-    </message>
-    <message>
-        <source>Old password</source>
-        <translation>舊密碼</translation>
-    </message>
-    <message>
-        <source>New password</source>
-        <translation>新密碼</translation>
-    </message>
-    <message>
-        <source>Repeat new password</source>
-        <translation>重複新密碼</translation>
-    </message>
-    <message>
-        <source>Password hint (Optional)</source>
-        <translation>密碼提示（選填）</translation>
-    </message>
-    <message>
-        <source>Passwords do not match</source>
-        <translation>密碼不一致</translation>
-    </message>
-    <message>
-        <source>The hint is visible to all users. Do not include the password here.</source>
-        <translation>密碼提示對所有人可見，切勿包含具體密碼訊息</translation>
-    </message>
-    <message>
-        <source>New password should differ from the current one</source>
-        <translation>新密碼和舊密碼不能相同</translation>
-    </message>
-    <message>
-        <source>Password changed</source>
-        <translation>密碼修改成功</translation>
-    </message>
-    <message>
-        <source>Wrong password</source>
-        <translation>密碼錯誤</translation>
-    </message>
-</context>
-<context>
-    <name>ControlWidget</name>
-    <message>
-        <source>Desktop Environment and Display Protocol</source>
-        <translation>桌面環境與顯示協議</translation>
-    </message>
-    <message>
-        <source>Keyboard Layout</source>
-        <translation>鍵盤布局</translation>
-    </message>
-    <message>
-        <source>Switch User</source>
-        <translation>切換使用者</translation>
-    </message>
-    <message>
-        <source>Power</source>
-        <translation>電源</translation>
+        <source>Wrong Password</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -279,6 +243,17 @@
         <source>Cancel</source>
         <translation>取消</translation>
     </message>
+    <message>
+        <source>The reason of inhibit.</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>LighterGreeter</name>
+    <message>
+        <source>Standard Mode</source>
+        <translation>標準模式</translation>
+    </message>
 </context>
 <context>
     <name>LockContent</name>
@@ -288,18 +263,18 @@
     </message>
     <message>
         <source>Failed to lock screen</source>
-        <translation>鎖定螢幕失敗</translation>
+        <translation>無法鎖定螢幕</translation>
     </message>
 </context>
 <context>
     <name>LockWorker</name>
     <message>
         <source>Fingerprint verification timed out, please enter your password manually</source>
-        <translation>指紋密碼驗證超時，請手動輸入密碼</translation>
+        <translation>指紋驗證逾時，請手動輸入密碼</translation>
     </message>
     <message>
         <source>Failed to match fingerprint</source>
-        <translation>指紋解鎖失敗</translation>
+        <translation>無法進行指紋配對</translation>
     </message>
 </context>
 <context>
@@ -310,7 +285,7 @@
     </message>
     <message>
         <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
-        <translation>此電腦還有以上帳戶在登入，關閉電腦會導致其資料遺失，是否要關閉此電腦？</translation>
+        <translation>以上的使用者仍在登入，且關機後這些使用者的資料將會遺失。確定關機？</translation>
     </message>
     <message>
         <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
@@ -318,69 +293,10 @@
     </message>
 </context>
 <context>
-    <name>PasswordLevelWidget</name>
+    <name>SessionWidget</name>
     <message>
-        <source>Weak</source>
-        <translation>強度低</translation>
-    </message>
-    <message>
-        <source>Medium</source>
-        <translation>強度中</translation>
-    </message>
-    <message>
-        <source>Strong</source>
-        <translation>強度高</translation>
-    </message>
-</context>
-<context>
-    <name>PwqualityManager</name>
-    <message>
-        <source>Password cannot be empty</source>
-        <translation>密碼不能為空</translation>
-    </message>
-    <message>
-        <source>Password must have at least %1 characters</source>
-        <translation>密碼長度不能少於%1個字元</translation>
-    </message>
-    <message>
-        <source>Password must be no more than %1 characters</source>
-        <translation>密碼長度不能超過%1個字元</translation>
-    </message>
-    <message>
-        <source>Password can only contain English letters (case-sensitive), numbers or special symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
-        <translation>密碼只能由英文（區分大小寫）、數字或特殊符號（~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/）組成</translation>
-    </message>
-    <message>
-        <source>No more than %1 palindrome characters please</source>
-        <translation>回文字元長度不超過%1位</translation>
-    </message>
-    <message>
-        <source>No more than %1 monotonic characters please</source>
-        <translation>單調性字元不超過%1位</translation>
-    </message>
-    <message>
-        <source>No more than %1 repeating characters please</source>
-        <translation>重複字元不超過%1位</translation>
-    </message>
-    <message>
-        <source>Password must contain uppercase letters, lowercase letters, numbers and symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
-        <translation>密碼必須由大寫字母、小寫字母、數字、符號（~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/）三種類型組成</translation>
-    </message>
-    <message>
-        <source>Password must not contain more than 4 palindrome characters</source>
-        <translation>密碼不得含有連續4個以上的回文字元</translation>
-    </message>
-    <message>
-        <source>Do not use common words and combinations as password</source>
-        <translation>密碼不能是常見單字及組合</translation>
-    </message>
-    <message>
-        <source>Create a strong password please</source>
-        <translation>密碼過於簡單，請增加密碼複雜度</translation>
-    </message>
-    <message>
-        <source>It does not meet password rules</source>
-        <translation>密碼不符合安全要求</translation>
+        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
+        <translation>您已開啟進階別等級保護，無法切換Wayland模式，請於“安全中心”關閉進階別等級保護後再試</translation>
     </message>
 </context>
 <context>
@@ -391,7 +307,7 @@
     </message>
     <message>
         <source>Reboot</source>
-        <translation>重啟</translation>
+        <translation>重新啟動</translation>
     </message>
     <message>
         <source>Suspend</source>
@@ -403,19 +319,27 @@
     </message>
     <message>
         <source>Lock</source>
-        <translation>鎖定</translation>
+        <translation>鎖定螢幕</translation>
     </message>
     <message>
         <source>Log out</source>
-        <translation>註銷</translation>
+        <translation>登出</translation>
+    </message>
+    <message>
+        <source>Switch user</source>
+        <translation>切換使用者</translation>
     </message>
     <message>
         <source>Switch system</source>
         <translation>切換系統</translation>
     </message>
     <message>
-        <source>Switch user</source>
-        <translation>切換使用者</translation>
+        <source>Update and Shut Down</source>
+        <translation>更新並關機</translation>
+    </message>
+    <message>
+        <source>Update and Reboot</source>
+        <translation>更新並重啟</translation>
     </message>
 </context>
 <context>
@@ -426,52 +350,79 @@
     </message>
 </context>
 <context>
-    <name>UserListPopupWidget</name>
+    <name>UdcpMFALoginWidget</name>
     <message>
-        <source>Standard User</source>
-        <translation>標準使用者</translation>
+        <source>发送验证码</source>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <source>Administrator</source>
-        <translation>管理員</translation>
+        <source>请输入手机号</source>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <source>Other Users</source>
-        <translation>其他使用者</translation>
+        <source>请输入验证码</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>获取验证码</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
-    <name>VirtualKeyboardModule</name>
+    <name>UpdateWorker</name>
     <message>
-        <source>Onboard</source>
-        <translation>螢幕鍵盤</translation>
+        <source>Update</source>
+        <translation>更新</translation>
+    </message>
+    <message>
+        <source>Please plug in and then install updates.</source>
+        <translation>請插入電源後再開始更新</translation>
+    </message>
+</context>
+<context>
+    <name>UsersWithTheSameName</name>
+    <message>
+        <source>Return</source>
+        <translation>返回</translation>
+    </message>
+    <message>
+        <source>Please select the account for login</source>
+        <translation>請選擇登入的帳戶</translation>
+    </message>
+    <message>
+        <source>Local Account</source>
+        <translation>本機帳戶</translation>
+    </message>
+    <message>
+        <source>Domain Account</source>
+        <translation>域帳戶</translation>
     </message>
 </context>
 <context>
     <name>WarningContent</name>
     <message>
         <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
-        <translation>以上程式阻止關機，強制關機可能會導致其資料遺失。</translation>
+        <translation>這些程式導致電腦不能關機。強制關機可能會導致資料遺失。</translation>
     </message>
     <message>
         <source>To close the program, click Cancel, and then close the program.</source>
-        <translation>您可以點擊“取消”然後關閉這些程式。</translation>
+        <translation>如要關閉程式，請按下「取消」後關閉程式。</translation>
     </message>
     <message>
         <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
-        <translation>以上程式阻止重啟，強制重啟可能會導致其資料遺失。</translation>
+        <translation>這些程式導致電腦不能重新開機。強制重新開機可能會導致資料遺失。</translation>
     </message>
     <message>
         <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
-        <translation>以上程式阻止待機，強制待機可能會導致其資料遺失。</translation>
+        <translation>這些程式導致電腦不能待機。強制待機可能會導致資料遺失。</translation>
     </message>
     <message>
         <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
-        <translation>以上程式阻止休眠，強制休眠可能會導致其資料遺失。</translation>
+        <translation>這些程式導致電腦不能休眠。強制休眠可能會導致資料遺失。</translation>
     </message>
     <message>
         <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
-        <translation>以上程式阻止註銷，強制註銷可能會導致其資料遺失。</translation>
+        <translation>這些程式導致電腦不能登出。強制登出可能會導致資料遺失。</translation>
     </message>
     <message>
         <source>Shut down</source>
@@ -479,7 +430,7 @@
     </message>
     <message>
         <source>Reboot</source>
-        <translation>重啟</translation>
+        <translation>重新啟動</translation>
     </message>
     <message>
         <source>Suspend</source>
@@ -491,19 +442,46 @@
     </message>
     <message>
         <source>Log out</source>
-        <translation>註銷</translation>
+        <translation>登出</translation>
     </message>
     <message>
         <source>Are you sure you want to shut down?</source>
-        <translation>您確定要關機嗎？</translation>
+        <translation>確定關機？</translation>
     </message>
     <message>
         <source>Are you sure you want to reboot?</source>
-        <translation>您確定要重啟嗎？</translation>
+        <translation>確定重開機？</translation>
     </message>
     <message>
         <source>Are you sure you want to log out?</source>
-        <translation>您確定要註銷嗎？</translation>
+        <translation>確定登出？</translation>
+    </message>
+    <message>
+        <source>Update and Shut Down</source>
+        <translation>更新並關機</translation>
+    </message>
+    <message>
+        <source>Update and Reboot</source>
+        <translation>更新並重啟</translation>
+    </message>
+    <message>
+        <source>Closing the programs and shutting down, please wait...</source>
+        <translation>正在關閉以上程式並關機，請稍後...</translation>
+    </message>
+    <message>
+        <source>Closing the programs and rebooting, please wait...</source>
+        <translation>正在關閉以上程式並重啟，請稍後...</translation>
+    </message>
+    <message>
+        <source>Closing the programs and logging out, please wait...</source>
+        <translation>正在關閉以上程式並註銷，請稍後...</translation>
+    </message>
+</context>
+<context>
+    <name>dss::module::AssistLoginWidget</name>
+    <message>
+        <source>Automatic login</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
